import random
chars1='abcdefghijklmnopqrstuvwxyz1234567890ABCDEFGHIJKLMNOPQRSTUVWXYZ'
chars2 = 'abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ'

def start():
    print('Welcome to the Random Password Generator. Version 1.00')
    print("------------------------------------")

  
    length = int(input('How much characters would you like your password to be? '))
    number = int(input('How many passwords would you like to generate? '))
    want_numbers = input('Would you like to have numbers in your password? (yes/no) ').lower()
    print('Here is a list of passwords generated')
    if want_numbers == 'yes':
        for __doc__ in range(number):
            password = ''
            for _ in range(length):
                password += random.choice(chars1)
            print(password)
        print(password)
    elif want_numbers == 'no':
        for __doc__ in range(number):
            password = ''
            for _ in range(length):
                password += random.choice(chars2)
            print(password)
start()


def main():
    print('Welcome to AIO Toolbox')
    while True:
        print('------------------------------------------')
        print('Mode 1: Currency Conversion Calculater')
        print('Mode 2: eBay View bot')
        print('Mode 3: Random Password generator')
        print('Mode 4: US Mint ATC Link Generator ')
        print('Mode 5: SNKR Early link Gen')
        mode_choice = input('What mode would you like to use? ')

        if mode_choice == '1':
            import Currency_conversion
            Currency_conversion.currency_convert()
            choice_x = input('Type F to close the program and A to use another module ')
            if choice_x == 'F':
                quit()
            elif choice_x == 'A':
                pass
        elif mode_choice == '2':
            import ebayviewer
            ebayviewer.start()
            choice_x = input('Type F to close the program and A to use another module ')
            if choice_x == 'F':
                quit()
            elif choice_x == 'A':
                pass
        elif mode_choice == '3':
            import randompassgen
            randompassgen.start()
            choice_x = input('Type F to close the program and A to use another module ')
            if choice_x == 'F':
                quit()
            elif choice_x == 'A':
                pass
        elif mode_choice == '4':
            import usmint_atc
            usmint_atc.start()
            choice_x = input('Type F to close the program and A to use another module ')
            if choice_x == 'F':
                quit()
            elif choice_x == 'A':
                pass
        elif mode_choice == '5':
            import snkrs_el
            snkrs_el.start()
            choice_x = input('Type F to close the program and A to use another module ')
            if choice_x == 'F':
                quit()
            elif choice_x == 'A':
                pass

if __name__ == "__main__":
    main()


import requests
from bs4 import BeautifulSoup
from fake_headers import Headers

headers = Headers(os="mac", headers=True).generate()
s = requests.Session()
#Sets the header and sets the session
def start():
    product_url = input('What is the url of the product? ')
    scrape_product = s.get(product_url, headers=headers).text
    soup1 = BeautifulSoup(scrape_product, 'lxml')
    product_id = soup1.find('input', {"id": "pid"})
    atc_link = f"https://catalog.usmint.gov/on/demandware.store/Sites-USM-Site/default/Cart-MiniAddProduct?pid={product_id.get('value')}"
    print('Your atc link is:', atc_link)


import requests
from bs4 import BeautifulSoup

def currency_convert():
    print('Currency names:')
    print('USD: US Dollar')
    print('EUR: Euro')
    print('CAD: Canadian dollar')
    print('PHP: Philippine peso')
    print('JPY: Japanese Yen')
    print('AUD: Australian Dollar')
    print('GPB British Pound')
    convert_from = input('What currency would you like to convert from? ')
    convert_to = input('What currency would you like to convert too? ')
    convert_amount = input('How much of that currency would you like to convert? ')
    url = f"https://www.x-rates.com/calculator/?from={convert_from}&to={convert_to}&amount={convert_amount}"
    r = requests.get(url).text
    soup1 = BeautifulSoup(r, 'lxml')
    final_ammount = soup1.find('span', class_='ccOutputRslt').text
    print(convert_amount, convert_from, 'is', final_ammount)


